@@ -20,10 +20,17 @@ try:
 except RuntimeError,e:
       print e.args[0]
 
-try:
-      t.hosed()
-except example.Exc,e:
-      print e.code, e.msg
+if not example.is_python_builtin():
+  try:
+        t.hosed()
+  except example.Exc,e:
+        print e.code, e.msg
+else:
+  try:
+        t.hosed()
+  except BaseException,e:
+        # Throwing builtin classes as exceptions not supported (-builtin option)
+        print e
 
 for i in range(1,4):
       try:
