@@ -1,5 +1,8 @@
 from li_boost_shared_ptr_bits import *
 
+def is_new_style_class(cls):
+  return hasattr(cls, "__class__")
+
 def check(nd):
   nd.i = 200
   i = nd.i
@@ -30,5 +33,8 @@ if sum != 66:
   raise "sum is wrong"
 
 ################################
-p = HiddenDestructor.create()
+if is_new_style_class(HiddenDestructor):
+  p = HiddenDestructor.create()
+else:
+  p = HiddenDestructor_create()
 
